EncryptionOptions

Struct EncryptionOptions 

pub struct EncryptionOptions<'a> {
    pub password: Option<&'a String>,
    pub keep_original_name: bool,
    pub generate_padding: bool,
    pub encrypt_metadata: bool,
    pub output_paths: Option<VecDeque<PathBuf>>,
}

Fields

password: Option<&'a String>

Pre-supplied password for authentication

keep_original_name: bool

Don’t replace the name with a random UUID for the encrypted file

generate_padding: bool

Generate random padding bytes and append them to the file. If set to false, can save some disk space for the file

encrypt_metadata: bool

Whether to encrypt original file metadata like file name, extension, modify time, etc. Enabling this feature provides better data protection, but the file will be unable to parse from the outside without properly decrypting (e.g. encrypted file search by its original name will be unavailable)

output_paths: Option<VecDeque<PathBuf>>

Contains an output path for each file